@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::HammersmithCity;
 
-$Map::Tube::London::Line::HammersmithCity::VERSION   = '1.15';
+$Map::Tube::London::Line::HammersmithCity::VERSION   = '1.16';
 $Map::Tube::London::Line::HammersmithCity::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::HammersmithCity - London Tube Map: Hammersmith & City L
 
 =head1 VERSION
 
-Version 1.15
+Version 1.16
 
 =head1 DESCRIPTION
 
@@ -57,69 +57,117 @@ London Tube Map: Hammersmith & City Line.
 =over 2
 
 =item * The station "Aldgate East" is also part of
-          L<District Line|Map::Tube::London::Line::District>.
+          L<District Line|Map::Tube::London::Line::District>
+
+=item * The station "Baker Street" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+        | L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
+        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
+
+=item * The station "Barbican" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
 
 =item * The station "Barking" is also part of
-          L<District Line|Map::Tube::London::Line::District>.
-
-=item * The station "Bromley-by-Bow" is also part of
-          L<District Line|Map::Tube::London::Line::District>.
+          L<District Line|Map::Tube::London::Line::District>
+        | L<Overground Line|Map::Tube::London::Line::Overground>
 
 =item * The station "Bow Road" is also part of
-          L<District Line|Map::Tube::London::Line::District>.
+          L<District Line|Map::Tube::London::Line::District>
+
+=item * The station "Bromley-by-Bow" is also part of
+          L<District Line|Map::Tube::London::Line::District>
 
 =item * The station "East Ham" is also part of
-          L<District Line|Map::Tube::London::Line::District>.
-
-=item * The station "Upton Park" is also part of
-          L<District Line|Map::Tube::London::Line::District>.
-
-=item * The station "Mile End" is also part of
           L<District Line|Map::Tube::London::Line::District>
-        | L<Central Line|Map::Tube::London::Line::Central>
-
-=item * The station "Plaistow" is also part of
-          L<District Line|Map::Tube::London::Line::District>.
-
-=item * The station "West Ham" is also part of
-          L<District Line|Map::Tube::London::Line::District>
-        | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
-        | L<Dockland Light Railway Line|Map::Tube::London::Line::DLR>.
-
-=item * The station "Paddington" is also part of
-          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
-        | L<District Line|Map::Tube::London::Line::District>.
 
 =item * The station "Edgware Road" is also part of
-          L<Circle Line|Map::Tube::London::Line::Circle>
-        | L<District Line|Map::Tube::London::Line::District>.
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+        | L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<District Line|Map::Tube::London::Line::District>
 
-=item * The station "King's Cross St Pancras" is also part of
+=item * The station "Euston Square" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
+
+=item * The station "Farringdon" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
+
+=item * The station "Goldhawk Road" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Great Portland Street" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
+
+=item * The station "Hammersmith" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<District Line|Map::Tube::London::Line::District>
+        | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
+
+=item * The station "King's Cross St. Pancras" is also part of
           L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
         | L<Northern Line|Map::Tube::London::Line::Northern>
         | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
-        | L<Victoria Line|Map::Tube::London::Line::Victoria>.
+        | L<Victoria Line|Map::Tube::London::Line::Victoria>
+
+=item * The station "Ladbroke Grove" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Latimer Road" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Liverpool Street" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>
+        | L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
+
+=item * The station "Mile End" is also part of
+          L<Central Line|Map::Tube::London::Line::Central>
+        | L<District Line|Map::Tube::London::Line::District>
 
 =item * The station "Moorgate" is also part of
           L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
-        | L<Northern Line|Map::Tube::London::Line::Northern>.
+        | L<Northern Line|Map::Tube::London::Line::Northern>
 
-=item * The station "Liverpool Street" is also part of
-          L<Circle Line|Map::Tube::London::Line::Circle>
-        | L<Central Line|Map::Tube::London::Line::Central>
-        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
+=item * The station "Paddington" is also part of
+          L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+        | L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<District Line|Map::Tube::London::Line::District>
 
-=item * The station "Baker Street" is also part of
+=item * The station "Plaistow" is also part of
+          L<District Line|Map::Tube::London::Line::District>
+
+=item * The station "Royal Oak" is also part of
           L<Circle Line|Map::Tube::London::Line::Circle>
-        | L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
+
+=item * The station "Shepherd's Bush Market" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+
+=item * The station "Stepney Green" is also part of
+          L<District Line|Map::Tube::London::Line::District>
+
+=item * The station "Upton Park" is also part of
+          L<District Line|Map::Tube::London::Line::District>
+
+=item * The station "West Ham" is also part of
+          L<DLR Line|Map::Tube::London::Line::Dlr>
+        | L<District Line|Map::Tube::London::Line::District>
         | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
-        | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
+
+=item * The station "Westbourne Park" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
 
 =item * The station "Whitechapel" is also part of
           L<District Line|Map::Tube::London::Line::District>
-        | L<London Overground Line|Map::Tube::London::Line::Overground>.
+        | L<Overground Line|Map::Tube::London::Line::Overground>
+
+=item * The station "Wood Lane" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
 
 =back
 
